Juniper.JUNOS
=============

====== =============================================
Vendor `Juniper Networks <http://www.juniper.net/>`_
OS     JUNOS
====== =============================================

Juniper.JUNOS profile supports JUNOS and JUNOS ES based routers and firewalls

Tested Equipment
----------------
.. supported:: Juniper.JUNOS
